@@ -19,7 +19,7 @@
 #ifndef __testlink_h
 #define __testlink_h
 
-#include <QtCore/QObject>
+#include <QObject>
 
 #include <kio/job.h>
 #include <kbookmark.h>
